# As discussed in the Fedora packaging mailing list
# the package is named tor-arm as in Debian to avoid conflicts
# http://lists.fedoraproject.org/pipermail/packaging/2011-October/007945.html
%global realname arm

Name:           tor-arm
Version:        1.4.4.1
Release:        12%{?dist}
Summary:        Terminal status monitor for Tor

Group:          Applications/Communications
License:        GPLv3
URL:            http://www.atagar.com/arm/
Source0:        https://archive.torproject.org/%{realname}/%{realname}-%{version}.tar.bz2
Source1:        %{name}.svg
Source2:        %{name}.desktop
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  desktop-file-utils
Requires:       python >= 2.5.0
Requires:       pytorctl
Requires:       python-cagraph

%description
The anonymizing relay monitor (arm) is a terminal status monitor for Tor relays,
intended for command-line aficionados, ssh connections, and anyone with a tty
terminal. This works much like top does for system usage, providing real time
statistics for:

 - bandwidth, CPU, and memory usage
 - relay's current configuration
 - logged events
 - connection details (IP, host name, fingerprint, and consensus data)
 - etc.


%package devel
Summary:        Development files for tor-arm
Group:          Development/System
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains example code for building a setuid binary and be able to
modify Tor config at run time


%prep
%setup -q -n %{realname}


%build
%{__python} setup.py build


%install
rm -rf %{buildroot}
%{__python} setup.py install --skip-build --root=%{buildroot}
# Remove unnecessary installed files
rm -rf %{buildroot}%{_docdir}
rm -f %{buildroot}%{_datadir}/%{realname}/uninstall \
      %{buildroot}%{_datadir}/%{realname}/resources/arm.1 \
      %{buildroot}%{_datadir}/%{realname}/resources/torrcOverride/override.c \
      %{buildroot}%{_datadir}/%{realname}/resources/torrcOverride/override.h
# This lives in pytorctl
rm -rf %{buildroot}%{_datadir}/%{realname}/TorCtl
chmod 0755 %{buildroot}%{_datadir}/%{realname}/starter.py \
           %{buildroot}%{_datadir}/%{realname}/test.py
install -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps \
           %{buildroot}%{_datadir}/applications
install -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2} 


%clean
rm -rf %{buildroot}


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%defattr(-,root,root,-)
%doc ChangeLog LICENSE README armrc.sample
%{_mandir}/man1/%{realname}.1.*
%{_bindir}/%{realname}
%{_datadir}/%{realname}
%{_datadir}/%{realname}-%{version}*.egg-info
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop


%files devel
%doc src/resources/torrcOverride/override.c src/resources/torrcOverride/override.h


%changelog
* Wed Apr 25 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-12
- Create devel subpackage

* Wed Apr 25 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-11
- Add wildcard to man page in the files section

* Thu Apr 19 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-10
- Remove Tor onion from icon due to Tor trademark reasons

* Wed Apr 18 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-9
- Add icon and desktop file
- Change build and install commands

* Thu Apr 12 2012 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-8
- Change realname variable to global
- Drop unnecessary python_sitelib definition
- Add example C code to documentation

* Thu Dec 22 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-7
- Remove python_sitearch definition
- Remove patch

* Tue Dec 13 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-6
- Change package name of the cagraph dependency

* Tue Oct 11 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-5
- Package name changed to tor-arm

* Mon Oct 10 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-4
- Minor fixes

* Sun Oct 09 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-3
- Require python >= 2.5.0

* Sun Oct 02 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-2
- Improved compatibility with Suse

* Fri Sep 30 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.1-1
- Updated to version 1.4.4.1

* Tue Sep 27 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-3
- noarch exception for EPEL

* Tue Sep 27 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-2
- Separate cagraph and TorCtl in different packages

* Fri Sep 23 2011 Juan Orti Alcaine <j.orti.alcaine@gmail.com> - 1.4.4.0-1
- First edition of the package
